#!/bin/sh
# 
# Terminus font 4.20 build for zenwalk 4.8
# source is from: http://www.is-vn.bg/hamster/jimmy-en.html
##
# variants included in my package: ge1, gq2, ka2, kx3* , and the new .ttf**
# if more are needed I can do it or you can run this script with the 
# variant's diff in CWD
#
# pkgd by: perry hargrave aka bioe007 < bioe007list <at> hotmail <dot> com
#
# notes: 
# 	* kx3 patch fails 1 hunk /249 - still seems to work I have no
# 	idea how to fix it, it seems to be looking for '780C' but I find 180C 
# 	in ter-u32n.bdf, havent time to check if another patch modifies this or not
#
#	** on source page link is provided to truetype font, i include that with this
#	package, but it is not 'built'

# ------ Verify Script
if [ "$(id -u)" != "0" ]; then
	echo "This script must be run as root!"
	exit
fi

# parse CLI options
while [ "$#" -gt "0" ] ; do
	case "$1" in
		*-nocleanup)
			CLEAN="FALSE"
			;;
		*-help | *h )
			echo \
			"Zenwalk ${0} script:
				--nocleanup    Do NOT Cleanup of Post build and Temporary Repo
				--help         Displays this help"
			exit
			;;
	esac
	shift
done

#script control vars
CLEAN=${CLEAN:-"TRUE"}

# build vars
CWD=`pwd`
NAME="terminus-font"
VERS=${VERS:-"4.20"}
ARCH="noarch"
BUILD=${BUILD:-50.1}

# filenames
NAME_SRC_BASE=${NAME}-${VERS}
NAME_PKG=${NAME}-${VERS}-${ARCH}-${BUILD}

# sources
SOURCE=( 
	http://www.is-vn.bg/hamster/$NAME-$VERS.tar.gz
	http://www.is-vn.bg/hamster/$NAME-$VERS-ge1.diff.gz
	http://www.is-vn.bg/hamster/$NAME-$VERS-gq2.diff.gz
	http://www.is-vn.bg/hamster/$NAME-$VERS-ka2.diff.gz
	http://www.is-vn.bg/hamster/$NAME-$VERS-kx3.diff.gz
	http://www.is-vn.bg/hamster/TerminusRe33-Bold.ttf
	)

# build options
CFLAGS=${CFLAGS:-"-O2 -pipe -march=i486 -mtune=i686"}
CXXFLAGS=${CFLAGS}
CONFOPTS="--prefix=/usr --psfdir=/usr/share/kbd/consolefonts --x11dir=/usr/share/fonts/misc"

# directories
DIR_TMP=$CWD/build
DIR_PKG=$DIR_TMP/package-$NAME
DIR_SRC=$DIR_TMP/$NAME_SRC_BASE 

echo "Removing previous build."
rm -rf $DIR_TMP

if [ ! -e $NAME_SRC_BASE.tar.gz ]; then
	echo "Sources not found, downloading"
	wget -c $SOURCE
	echo "\nNow verify the downloads and rerun the build script."
	exit 0 
fi

mkdir -p ${DIR_TMP} ${DIR_PKG} ${DIR_SRC} ${DIR_PKG}/install

# extract sources
cd $DIR_TMP
tar xvfz $CWD/$NAME_SRC_BASE.tar.gz

# apply variant patches - I included: ge1, gq2, ka2, kx3 - let me know if others are wanted.
cd $DIR_SRC
for i in `ls $CWD/*.diff.gz 2> /dev/null` ; do zcat $i | patch -p1  ; done

# configure
./configure $CONFOPTS 

# compile and install to pkg dir
make || exit 1
make DESTDIR=${DIR_PKG} install install-12b install install-uni install-ref install-pcf fontdir 

install -d -m755 ${DIR_PKG}/install 

# handles documentation
#	gzip man pages
#	copy readme's & the like
#	copy build scipt
docs() {
	# gzip man pages
	find ${DIR_PKG}/usr/man -type f -exec gzip -9f {} \;
	
	# documentation
	install -d -m755 ${DIR_PKG}/usr/doc/${NAME_SRC_BASE}/
	cp -v AUTHORS* COPYING* INSTALL* NEWS* README* ChangeLog* ${DIR_PKG}/usr/doc/${NAME_SRC_BASE}/
	# redundant documentation
	if [ -d ${DIR_PKG}/usr/share/doc ]; then
		( cd ${DIR_PKG}/usr/share/doc ; mv -v * ${DIR_PKG}/usr/doc/${NAME}-${VERSION}/${1} )
		rm -rf ${DIR_PKG}/usr/share/doc
	fi
	
	# build script
	mkdir -p ${DIR_PKG}/usr/src/${NAME_SRC_BASE}
	cp -v $CWD/build-${NAME}.sh ${DIR_PKG}/usr/src/${NAME_SRC_BASE}
}

#slack desc
slack_desc() {
cat > ${DIR_PKG}/install/slack-desc << EoF
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description. Line
# up the first '|' above the ':' following the base package name, and the '|' 
# on the right side marks the last column you can put a character in. You must
# make exactly 11 lines for the formatting to be correct. It's also customary
# to leave one space after the ':'.

       |----handy-ruler-------------------------------------------------|
${NAME}: Terminus Font (A clean fixed width console and X11 font)
${NAME}:
${NAME}: Terminus Font is designed for long (8 and more hours per day)
${NAME}: work with computers. Version 4.20 contains 690 characters and
${NAME}: covers code pages ISO8859-1/2/5/9/13/15/16,
${NAME}: Windows-1250/1251/1252/1254/1257, Paratype-PT154/PT254,
${NAME}: Bulgarian-MIK, Macintosh-Ukrainian, Esperanto,KOI8-R/U/E/F,
${NAME}: IBM-437/852/855/866 and many others (a total of about 110
${NAME}: language sets). Also included are the IBM VGA, vt100 and xterm
${NAME}: pseudographic characters.
${NAME}:
EoF

}

# make a doinst.sh to update font dirs and cache
doinst() {
install -v -d -m755 ${DIR_PKG}/install
cat > ${DIR_PKG}/install/doinst.sh << "EoF"
# echo ""
# echo "Updating Fonts..."
# Font caching :)
for fontdir in cyrillic OTF TTF 100dpi 75dpi misc Type1 Speedo util encodings; do
	[ -d usr/share/fonts/${fontdir} ] && \
	( 
		[ -x usr/bin/mkfontscale ] && ( chroot . usr/bin/mkfontscale usr/share/fonts/${fontdir} > /dev/null 2>&1 )
		[ -x usr/bin/mkfontdir ] && ( chroot . usr/bin/mkfontdir usr/share/fonts/${fontdir} > /dev/null 2>&1 )
	)
done
# Force MegaUltra re-cache!
if [ -d var/cache/fontconfig ]; then
	rm -rf var/cache/fontconfig
	mkdir -p var/cache/fontconfig
fi
[ -x usr/bin/fc-cache ] && usr/bin/fc-cache -rf > /dev/null 2>&1
# echo "Complete."
EoF
}

docs
slack_desc
doinst

cd $DIR_PKG
# ------ Finalize
# strip
find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# copy .ttf font
mkdir -p $DIR_PKG/usr/share/fonts/TTF
cp -v $CWD/*.ttf $DIR_PKG/usr/share/fonts/TTF

# all font names should be lowercase
cd $DIR_PKG/usr/share/
for file in ./fonts/TTF/* ./fonts/misc/* ./kbd/consolefonts/* ; do 
	path=${file%%$(basename $file)}
	mv "$file" "${path}$(echo $( basename $file ) | tr [A-Z] [a-z] )" 2>&1
done

# now make the package
cd $DIR_PKG
makepkg -l y -c n $CWD/$NAME_PKG.tgz ; 

# administravia
cd $CWD
md5sum ${NAME_PKG}.tgz > ${NAME_PKG}.md5
requiredbuilder -z ${NAME_PKG}.tgz > ${NAME_PKG}.dep

if [ "${CLEAN}" = "TRUE" ] ; then
	echo "Cleaning up $TMP"
 	rm -rf $DIR_TMP > /dev/null
fi

